==> A.i386-pc-linux-suse8.2.tar.gz: A.i386-pc-linux-suse8.2/fsinfo/fsi_gram.h <==
/* A Bison parser, made from ../../fsinfo/fsi_gram.y, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_FSI_GRAM_H
# define BISON_FSI_GRAM_H

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     tARCH = 258,
     tAS = 259,
     tAUTOMOUNT = 260,
     tCLUSTER = 261,
     tCONFIG = 262,
     tDUMPSET = 263,
     tEQ = 264,
     tNFSEQ = 265,
     tEXPORTFS = 266,
     tFREQ = 267,
     tFROM = 268,
     tFS = 269,
     tFSTYPE = 270,
     tHWADDR = 271,
     tINADDR = 272,
     tHOST = 273,
     tLOCALHOST = 274,
     tLOG = 275,
     tMOUNT = 276,
     tNETMASK = 277,
     tNETIF = 278,
     tVOLNAME = 279,
     tOPTS = 280,
     tOS = 281,
     tPASSNO = 282,
     tDIRECT = 283,
     tSEL = 284,
     tSTR = 285
   };
#endif
#define tARCH 258
#define tAS 259
#define tAUTOMOUNT 260
#define tCLUSTER 261
#define tCONFIG 262
#define tDUMPSET 263
#define tEQ 264
#define tNFSEQ 265
#define tEXPORTFS 266
#define tFREQ 267
#define tFROM 268
#define tFS 269
#define tFSTYPE 270
#define tHWADDR 271
#define tINADDR 272
#define tHOST 273
#define tLOCALHOST 274
#define tLOG 275
#define tMOUNT 276
#define tNETMASK 277
#define tNETIF 278
#define tVOLNAME 279
#define tOPTS 280
#define tOS 281
#define tPASSNO 282
#define tDIRECT 283
#define tSEL 284
#define tSTR 285




#ifndef YYSTYPE
#line 55 "../../fsinfo/fsi_gram.y"
typedef union {
	auto_tree *a;
	disk_fs *d;
	ether_if *e;
	host *h;
	qelem *q;
	char *s;
	fsi_mount *m;
	fsmount *f;
} yystype;
/* Line 1281 of /usr/share/bison/yacc.c.  */
#line 111 "fsi_gram.h"
# define YYSTYPE yystype
#endif

extern YYSTYPE yylval;


#endif /* not BISON_FSI_GRAM_H */

==> A.i386-pc-linux-suse9.1.tar.gz: A.i386-pc-linux-suse9.1/fsinfo/fsi_gram.h <==
/* A Bison parser, made by GNU Bison 1.875.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     tARCH = 258,
     tAS = 259,
     tAUTOMOUNT = 260,
     tCLUSTER = 261,
     tCONFIG = 262,
     tDUMPSET = 263,
     tEQ = 264,
     tNFSEQ = 265,
     tEXPORTFS = 266,
     tFREQ = 267,
     tFROM = 268,
     tFS = 269,
     tFSTYPE = 270,
     tHWADDR = 271,
     tINADDR = 272,
     tHOST = 273,
     tLOCALHOST = 274,
     tLOG = 275,
     tMOUNT = 276,
     tNETMASK = 277,
     tNETIF = 278,
     tVOLNAME = 279,
     tOPTS = 280,
     tOS = 281,
     tPASSNO = 282,
     tDIRECT = 283,
     tSEL = 284,
     tSTR = 285
   };
#endif
#define tARCH 258
#define tAS 259
#define tAUTOMOUNT 260
#define tCLUSTER 261
#define tCONFIG 262
#define tDUMPSET 263
#define tEQ 264
#define tNFSEQ 265
#define tEXPORTFS 266
#define tFREQ 267
#define tFROM 268
#define tFS 269
#define tFSTYPE 270
#define tHWADDR 271
#define tINADDR 272
#define tHOST 273
#define tLOCALHOST 274
#define tLOG 275
#define tMOUNT 276
#define tNETMASK 277
#define tNETIF 278
#define tVOLNAME 279
#define tOPTS 280
#define tOS 281
#define tPASSNO 282
#define tDIRECT 283
#define tSEL 284
#define tSTR 285




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 55 "../../fsinfo/fsi_gram.y"
typedef union YYSTYPE {
	auto_tree *a;
	disk_fs *d;
	ether_if *e;
	host *h;
	qelem *q;
	char *s;
	fsi_mount *m;
	fsmount *f;
} YYSTYPE;
/* Line 1249 of yacc.c.  */
#line 107 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
